Legend placements
=================

This page tests legend placement in plots.

.. report:: Trackers.SingleColumnDataLargeExample
   :render: line-plot 
   :transform: histogram 
   :width: 200

   Default is outer-top

Outer legends
-------------
.. report:: Trackers.SingleColumnDataLargeExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: outer-top
   :width: 200

   outer-top

.. report:: Trackers.SingleColumnDataLargeExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: outer-right
   :width: 200

   outer-right

Inner legends
-------------

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: upper-right
   :width: 200

   upper right

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: lower-right
   :width: 200

   lower right

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: center-right
   :width: 200

   center right

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: right
   :width: 200

   right

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: upper-left
   :width: 200

   upper left

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: lower-left
   :width: 200

   lower left

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: center-left
   :width: 200

   center left

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: lower-center
   :width: 200

   lower center

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: upper-center
   :width: 200

   upper center

.. report:: Trackers.SingleColumnDataExample
   :render: line-plot 
   :transform: histogram 
   :legend-location: center
   :width: 200

   center

